@@ -6,7 +6,7 @@ use crate::StrVec;
 use std::fmt::Debug;
 
 #[derive(BartDisplay, Debug, Default)]
-#[template = "templates/scanner_build_info.rs"]
+#[template = "templates/scanner_build_info.rs.tpl"]
 struct ScannerBuildInfo {
     scanner_index: usize,
     scanner_name: String,
@@ -52,7 +52,7 @@ impl ScannerBuildInfo {
 }
 
 #[derive(BartDisplay, Debug, Default)]
-#[template = "templates/lexer_template.rs"]
+#[template = "templates/lexer_template.rs.tpl"]
 struct LexerData {
     augmented_terminals: StrVec,
     used_token_constants: String,
@@ -122,7 +122,10 @@ pub fn generate_lexer_source(grammar_config: &GrammarConfig) -> Result<String> {
             .iter()
             .enumerate()
             .fold(Vec::new(), |mut acc, (i, e)| {
-                let n = generate_name(&acc, generate_terminal_name(e, i, &grammar_config.cfg));
+                let n = generate_name(
+                    &acc,
+                    generate_terminal_name(e, Some(i), &grammar_config.cfg),
+                );
                 acc.push(n);
                 acc
             });
@@ -167,7 +170,10 @@ pub fn generate_terminal_names(grammar_config: &GrammarConfig) -> Vec<String> {
         .iter()
         .enumerate()
         .fold(Vec::new(), |mut acc, (i, e)| {
-            let n = generate_name(&acc, generate_terminal_name(e, i, &grammar_config.cfg));
+            let n = generate_name(
+                &acc,
+                generate_terminal_name(e, Some(i), &grammar_config.cfg),
+            );
             acc.push(n);
             acc
         })
